@@ -6,7 +6,15 @@ from ssb_altinn3_util.clients.auth.helpers.secret_manager_client import SecretMa
 
 
 class AltinnAuthClient:
+    """
+    A client which can be used by ssb applications to retrieve access tokens for Altinn3.
+    Relevant clients and access to required subsystems is required, and must be configured in
+    advance.
+    """
     def __init__(self, config: AltinnAuthClientConfig):
+        """
+        :param config: Required configuration for the client.
+        """
         self.secret_client = SecretManagerClient(config.keycloak_secret_path)
         self.keycloak_client = KeycloakClient(config.platform_environment)
         self.guardian_client = GuardianClient(config.platform_environment)
@@ -14,6 +22,11 @@ class AltinnAuthClient:
         self.maskinport_client_id = config.maskinport_client_id
 
     def get_altinn_auth_token(self) -> str:
+        """
+        Used to retrieve an access token to the Altinn APIs.
+
+        :return: the requested token (if authorized)
+        """
         keycloak_secret = self.secret_client.get_secret()
         keycloak_token = self.keycloak_client.get_token(self.maskinport_client_id, keycloak_secret)
         maskinport_token = self.guardian_client.get_token(keycloak_token)
